@@ -1,3 +1,7 @@
+# Version: 30-11-2012, Daniel Fischer
+
+
+# this function creates the new vector of group labels
 createGroups <- function(g,desOrder){
   reG <- g
   curClass <- 1
@@ -8,4 +12,4 @@ createGroups <- function(g,desOrder){
     curClass <- curClass + 1
   }
   reG
-}
\ No newline at end of file
+} # End of function: createGroups
\ No newline at end of file
